@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2008  Michel de Boer <michel@twinklephone.com>
+    Copyright (C) 2005-2009  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <assert.h>
 #include <queue>
 #include <string>
+
 #include "audio_codecs.h"
 #include "audio_device.h"
 #include "audio_encoder.h"
@@ -35,6 +36,11 @@
 #include "twinkle_rtp_session.h"
 #include "twinkle_config.h"
 
+#ifdef HAVE_SPEEX
+#include <speex/speex.h>
+#include <speex/speex_preprocess.h> 
+#endif
+
 using namespace std;
 using namespace ost;
 
@@ -87,7 +93,7 @@ private:
 	t_audio_encoder	*audio_encoder;
 
 	// Buffer to store PCM samples for ptime ms
-	unsigned char	*sample_buf;
+	unsigned char	*input_sample_buf;
 	
 	// Indicates if NAT keep alive packets must be sent during silence
 	// suppression.
@@ -103,8 +109,8 @@ private:
 
 	// Queue of DTMF tones to be sent
 	struct t_dtmf_event {
-		uint8	dtmf_tone;
-		bool	inband;
+		t_dtmf_ev	dtmf_tone;
+		bool		inband;
 	};
 	
 	queue<t_dtmf_event>	dtmf_queue;
@@ -126,6 +132,14 @@ private:
 	// Timestamp for next RTP packet
 	unsigned long timestamp;
 
+#ifdef HAVE_SPEEX
+	/** Speex preprocessor state */
+	SpeexPreprocessState *speex_preprocess_state;
+	
+	/** Speex VAD enabled? */
+	bool speex_dsp_vad;
+#endif
+
 	// Get sound samples for 1 RTP packet from the soundcard.
 	// Returns false if the main loop has to start another cycle to get
 	// samples (eg. no samples available yet).
