@@ -41,6 +41,7 @@ string event_type2str(t_event_type t) {
 	case EV_ASYNC_RESPONSE:	return "EV_ASYNC_RESPONSE";
 	case EV_BROKEN_CONNECTION: return "EV_BROKEN_CONNECTION";
 	case EV_TCP_PING:	return "EV_TCP_PING";
+	case EV_FN_CALL:	return "EV_FN_CALL";
 	}
 
 	return "UNKNOWN";
@@ -384,7 +385,7 @@ void t_event_ui::set_codec(t_audio_codec _codec) {
 	codec = _codec;
 }
 
-void t_event_ui::set_dtmf_event(char _dtmf_event) {
+void t_event_ui::set_dtmf_event(t_dtmf_ev _dtmf_event) {
 	dtmf_event = _dtmf_event;
 }
 
@@ -505,6 +506,22 @@ unsigned short t_event_tcp_ping::get_dst_port(void) const {
 	return dst_port_;
 }
 
+///////////////////////////////////////////////////////////
+// class t_event_fncall
+///////////////////////////////////////////////////////////
+
+t_event_fncall::t_event_fncall(std::function<void()> fn)
+	: m_fn(fn) {
+
+}
+void t_event_fncall::invoke() {
+	m_fn();
+}
+
+t_event_type t_event_fncall::get_type(void) const {
+	return EV_FN_CALL;
+}
+
 ///////////////////////////////////////////////////////////
 // class t_event_queue
 ///////////////////////////////////////////////////////////
@@ -545,6 +562,12 @@ void t_event_queue::push_quit(void) {
 	push(event);
 }
 
+void t_event_queue::push_fncall(std::function<void()> fn) {
+	t_event_fncall* event = new t_event_fncall(fn);
+	MEMMAN_NEW(event);
+	push(event);
+}
+
 void t_event_queue::push_network(t_sip_message *m, const t_ip_port &ip_port) {
 	t_event_network	*event = new t_event_network(m);
 	MEMMAN_NEW(event);
