@@ -29,6 +29,7 @@
 #include "timekeeper.h"
 #include "stun/stun.h"
 #include "audio/audio_codecs.h"
+#include "audio/rtp_telephone_event.h"
 #include "parser/sip_message.h"
 #include "sockets/socket.h"
 #include "sockets/url.h"
@@ -58,6 +59,7 @@ enum t_event_type {
 	EV_ASYNC_RESPONSE,	/**< Response on an asynchronous question */
 	EV_BROKEN_CONNECTION,	/**< Persitent connection to SIP proxy broken */
 	EV_TCP_PING,		/**< Send a TCP ping (double CRLF) */
+	EV_FN_CALL,		/**< Queued function call */
 };
 
 /** Abstract parent class for all events */
@@ -496,7 +498,7 @@ private:
 	//@{
 	int		line;		/**< Line number. */
 	t_audio_codec	codec;		/**< Audio codec. */
-	char		dtmf_event;	/**< DTMF event. */
+	t_dtmf_ev	dtmf_event;	/**< DTMF event. */
 	bool		encrypted;	/**< Encryption indication. */
 	string		cipher_mode;	/**< Cipher mode (algorithm name). */
 	string		zrtp_sas;	/**< ZRTP SAS/ */
@@ -517,7 +519,7 @@ public:
 	//@{
 	void set_line(int _line);
 	void set_codec(t_audio_codec _codec);
-	void set_dtmf_event(char _dtmf_event);
+	void set_dtmf_event(t_dtmf_ev _dtmf_event);
 	void set_encrypted(bool on);
 	void set_cipher_mode(const string &_cipher_mode);
 	void set_zrtp_sas(const string &sas);
@@ -627,6 +629,14 @@ public:
 	//@}
 };
 
+class t_event_fncall : public t_event {
+public:
+	t_event_fncall(std::function<void()> fn);
+	void invoke();
+	virtual t_event_type get_type(void) const override;
+private:
+	std::function<void()> m_fn;
+};
 
 /**
  * Event queue.
@@ -663,6 +673,9 @@ public:
 	/** Push a quit event into the queue. */
 	void push_quit(void);
 
+	/** Push a queued function call */
+	void push_fncall(std::function<void()> fn);
+
 	/**
 	 * Create a network event and push it into the queue.
 	 * @param m [in] SIP message.
