@@ -17,6 +17,7 @@
 */
 
 #include "twinkle_config.h"
+#include <QtDebug>
 
 #ifdef HAVE_KDE
 #include <kapplication.h>
@@ -25,9 +26,9 @@
 
 #include <qapplication.h>
 #include <qtranslator.h>
-#include <qmime.h>
-#include <qprogressdialog.h>
 #include <qtextcodec.h>
+#include <QSettings>
+#include <QDir>
 
 #include "mphoneform.h"
 
@@ -36,6 +37,7 @@
 #include <cstdlib>
 #include <cstring>
 #include <ctime>
+#include <QtDebug>
 #include <unistd.h>
 
 #include "address_book.h"
@@ -61,6 +63,7 @@
 #include "threads/thread.h"
 #include "utils/mime_database.h"
 #include "audits/memman.h"
+#include <QLibraryInfo>
 
 using namespace std;
 using namespace utils;
@@ -165,6 +168,7 @@ pthread_t		thread_id_main;
 // Indicates if LinuxThreads or NPTL is active.
 bool			threading_is_LinuxThreads;
 
+QSettings*      g_gui_state;
 
 /**
  * Parse arguments passed to application
@@ -265,7 +269,7 @@ void parse_main_args(int argc, char **argv, bool &cli_mode, bool &override_lock_
 			cout << endl;
 			cout << " --set-profile <profile>\n";
 			cout << "\t\tMake <profile> the active profile.\n";
-			cout << "\t\tWhen using this option in conjuction with --call and --cmd,\n";
+			cout << "\t\tWhen using this option in conjunction with --call and --cmd,\n";
 			cout << "\t\tthen the profile is activated before executing --call or \n";
 			cout << "\t\t--cmd.\n";
 			cout << endl;
@@ -274,7 +278,7 @@ void parse_main_args(int argc, char **argv, bool &cli_mode, bool &override_lock_
 			cout << "\t\tand take focus.\n";
 			cout << endl;
 			cout << " --hide";
-			cout << "\t\tInstruct a running instance of Twinkle to hide in the sytem tray.\n";
+			cout << "\t\tInstruct a running instance of Twinkle to hide in the system tray.\n";
 			cout << "\t\tIf no system tray is used, then Twinkle will minimize.\n";
 			cout << endl;
 			cout << " --help-cli [cli command]\n";
@@ -288,7 +292,7 @@ void parse_main_args(int argc, char **argv, bool &cli_mode, bool &override_lock_
 		} else if (strcmp(argv[i], "--version") == 0) {
 			// Get version
 			QString s = sys_config->about(false).c_str();
-			cout << s;
+            cout << s.toStdString();
 			exit(0);
 		} else if (strcmp(argv[i], "-c") == 0) {
 			// CLI mode
@@ -312,7 +316,7 @@ void parse_main_args(int argc, char **argv, bool &cli_mode, bool &override_lock_
 					{
 						config_file += USER_FILE_EXT;
 					}
-					config_files.push_back(config_file.ascii());
+                    config_files.push_back(config_file.toStdString());
 				}
 			} else {
 				cout << argv[0] << ": ";
@@ -456,11 +460,11 @@ bool open_sip_socket(bool cli_mode) {
 		if (cli_mode) {
 			msg = QString("Failed to create a %1 socket (SIP) on port %2")
 			   .arg(sock_type)
-			   .arg(sys_config->get_sip_port()).ascii();
+               .arg(sys_config->get_sip_port()).toStdString();
 		} else {
 			msg = qApp->translate("GUI", "Failed to create a %1 socket (SIP) on port %2")
 			   .arg(sock_type)
-			   .arg(sys_config->get_sip_port()).ascii();
+               .arg(sys_config->get_sip_port()).toStdString();
 		}
 		msg += "\n";
 		msg += get_error_str(err);
@@ -472,7 +476,7 @@ bool open_sip_socket(bool cli_mode) {
 	return true;
 }
 
-QApplication *create_user_interface(bool cli_mode, int argc, char **argv, QTranslator *qtranslator) {
+QApplication *create_user_interface(bool cli_mode, int argc, char **argv, QTranslator *appTranslator, QTranslator *qtTranslator) {
 	QApplication *qa = NULL;
 	
 	if (cli_mode) {
@@ -486,7 +490,7 @@ QApplication *create_user_interface(bool cli_mode, int argc, char **argv, QTrans
 		// Store the defualt mime source factory for the embedded icons.
 		// This is created by Qt. The KApplication constructor seems to destroy
 		// this default.
-		QMimeSourceFactory *factory_qt = QMimeSourceFactory::takeDefaultFactory();
+		Q3MimeSourceFactory *factory_qt = Q3MimeSourceFactory::takeDefaultFactory();
 		
 		// Initialize the KApplication
 		KCmdLineArgs::init(argc, argv, "twinkle", PRODUCT_NAME, "Soft phone",
@@ -495,28 +499,43 @@ QApplication *create_user_interface(bool cli_mode, int argc, char **argv, QTrans
 		MEMMAN_NEW(qa);
 		
 		// Store the KDE mime source factory
-		QMimeSourceFactory *factory_kde = QMimeSourceFactory::takeDefaultFactory();
+		Q3MimeSourceFactory *factory_kde = Q3MimeSourceFactory::takeDefaultFactory();
 		
 		// Make the Qt factory the default to make the embedded icons work.
-		QMimeSourceFactory::setDefaultFactory(factory_qt);
+		Q3MimeSourceFactory::setDefaultFactory(factory_qt);
 		
 		// Add the KDE factory
-		QMimeSourceFactory::addFactory(factory_kde);
+		Q3MimeSourceFactory::addFactory(factory_kde);
 #else
-		int tmp = argc;
+		static int tmp = argc;
 		qa = new t_twinkle_application(tmp, argv);
 		MEMMAN_NEW(qa);
 #endif
+#if QT_VERSION < 0x050000 // In Qt5, these functions are removed. UTF-8 is the default.
 		QTextCodec::setCodecForCStrings(QTextCodec::codecForName("utf8"));
 		QTextCodec::setCodecForTr(QTextCodec::codecForName("utf8"));
+#endif
+
+        g_gui_state = new QSettings(QDir::home().absoluteFilePath(QString("%1/%2").arg(DIR_USER).arg("gui_state.ini")),
+                                    QSettings::IniFormat, qa);
 		
 		// Install Qt translator
 		// Do not report to memman as the translator will be deleted
 		// automatically when the QApplication is deleted.
-		qtranslator = new QTranslator(0);
-		qtranslator->load(QString("twinkle_") + QTextCodec::locale(), 
+		appTranslator = new QTranslator(0);
+		qtTranslator = new QTranslator(0);
+
+		QString langName = QLocale::system().name().left(2);
+
+		qDebug() << "Language name:" << langName;
+		appTranslator->load(QString("twinkle_") + langName,
 			QString(sys_config->get_dir_lang().c_str()));
-		qa->installTranslator(qtranslator);
+		qa->installTranslator(appTranslator);
+		
+		qtTranslator->load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+		qa->installTranslator(qtTranslator);
+
+		qa->setQuitOnLastWindowClosed(false);
 		
 		// Create translator for translation of strings from the core
 		translator = new t_qt_translator(qa);
@@ -529,6 +548,37 @@ QApplication *create_user_interface(bool cli_mode, int argc, char **argv, QTrans
 	return qa;
 }
 
+void blockSignals()
+{
+	// Dedicated thread will catch SIGALRM, SIGINT, SIGTERM, SIGCHLD signals,
+	// therefore all threads must block these signals. Block now, then all
+	// created threads will inherit the signal mask.
+	// In LinuxThreads the sigwait does not work very well, so
+	// in LinuxThreads a signal handler is used instead.
+
+	if (!threading_is_LinuxThreads) {
+		sigset_t sigset;
+		sigemptyset(&sigset);
+		sigaddset(&sigset, SIGALRM);
+		sigaddset(&sigset, SIGINT);
+		sigaddset(&sigset, SIGTERM);
+		sigaddset(&sigset, SIGCHLD);
+		sigprocmask(SIG_BLOCK, &sigset, NULL);
+	} else {
+		if (!phone->set_sighandler()) {
+			string msg = "Failed to register signal handler.";
+			log_file->write_report(msg, "::main", LOG_NORMAL, LOG_CRITICAL);
+			ui->cb_show_msg(msg, MSG_CRITICAL);
+			sys_config->delete_lock_file();
+			exit(1);
+		}
+	}
+
+	// Ignore SIGPIPE so read from broken sockets will not cause
+	// the process to terminate.
+	(void)signal(SIGPIPE, SIG_IGN);
+}
+
 int main( int argc, char ** argv )
 {
 	string error_msg;
@@ -542,8 +592,11 @@ int main( int argc, char ** argv )
 	// Determine threading implementation
 	threading_is_LinuxThreads = t_thread::is_LinuxThreads();
 
+	blockSignals();
+
 	QApplication *qa = NULL;
-	QTranslator *qtranslator = NULL;
+	QTranslator *appTranslator = NULL;
+	QTranslator *qtTranslator = NULL;
 	
 	// Store id of main thread
 	thread_id_main = t_thread::self();
@@ -613,8 +666,8 @@ int main( int argc, char ** argv )
 		
 		// Activate a profile in the running Twinkle process.
 		if (already_running && !g_cmd_args.cmd_set_profile.isEmpty()) {
-			cmdsocket::cmd_cli(string("user ") + g_cmd_args.cmd_set_profile.ascii(), true);
-			// Do not exit now as this option may be used in conjuction
+            cmdsocket::cmd_cli(string("user ") + g_cmd_args.cmd_set_profile.toStdString(), true);
+			// Do not exit now as this option may be used in conjunction
 			// with --call or --cmd
 			must_exit = true;
 		}
@@ -623,7 +676,7 @@ int main( int argc, char ** argv )
 		// is present, then send the call destination to the running
 		// Twinkle process.
 		if (already_running && !g_cmd_args.callto_destination.isEmpty()) {
-			cmdsocket::cmd_call(g_cmd_args.callto_destination.ascii(), 
+            cmdsocket::cmd_call(g_cmd_args.callto_destination.toStdString(),
 					    g_cmd_args.cmd_immediate_mode);
 			exit(0);
 		}
@@ -631,7 +684,7 @@ int main( int argc, char ** argv )
 		// If the --cmd parameter is present, send the cli command
 		// to the running Twinkle process
 		if (already_running && !g_cmd_args.cli_command.isEmpty()) {
-			cmdsocket::cmd_cli(g_cmd_args.cli_command.ascii(), 
+            cmdsocket::cmd_cli(g_cmd_args.cli_command.toStdString(),
 					   g_cmd_args.cmd_immediate_mode);
 			exit(0);
 		}
@@ -644,7 +697,7 @@ int main( int argc, char ** argv )
 	
 	// Read system configuration
 	bool sys_config_read = sys_config->read_config(error_msg);
-	qa = create_user_interface(cli_mode, remain_argc, remain_argv, qtranslator);
+	qa = create_user_interface(cli_mode, remain_argc, remain_argv, appTranslator, qtTranslator);
 	if (!sys_config_read) {
 		ui->cb_show_msg(error_msg, MSG_CRITICAL);
 		exit(1);
@@ -673,7 +726,7 @@ int main( int argc, char ** argv )
 				if (!cli_mode) {
 					msg += "\n\n";
 					msg += qApp->translate("GUI",
-						"Override lock file and start anyway?").ascii();
+                        "Override lock file and start anyway?").toStdString();
 				}
 				if (override_lock_file || ui->cb_ask_msg(msg, MSG_WARNING)) {
 					sys_config->delete_lock_file();
@@ -712,9 +765,9 @@ int main( int argc, char ** argv )
 	// shutdow and now gets restored.
 	if (qa && qa->isSessionRestored()) {
 		QString msg = "Restore session: " + qa->sessionId();
-		log_file->write_report(msg.ascii(), "::main");
+        log_file->write_report(msg.toStdString(), "::main");
 		
-		if (sys_config->get_ui_session_id() == qa->sessionId().ascii()) {
+        if (sys_config->get_ui_session_id() == qa->sessionId().toStdString()) {
 			config_files = sys_config->get_ui_session_active_profiles();
 			// Note: the GUI state is restore in t_gui::run()
 		} else {
@@ -735,7 +788,7 @@ int main( int argc, char ** argv )
 		{
 			QString config_file = (*i).c_str();
 			config_file += USER_FILE_EXT;
-			config_files.push_back(config_file.ascii());
+            config_files.push_back(config_file.toStdString());
 		}
 	}
 	
@@ -763,9 +816,9 @@ int main( int argc, char ** argv )
 					profile_selected = true;
 				} else {
 					if (cli_mode) {
-						error_msg = QString("The following profiles are both for user %1").arg(user_config.get_name().c_str()).ascii();
+                        error_msg = QString("The following profiles are both for user %1").arg(user_config.get_name().c_str()).toStdString();
 					} else {
-						error_msg = qApp->translate("GUI", "The following profiles are both for user %1").arg(user_config.get_name().c_str()).ascii();
+                        error_msg = qApp->translate("GUI", "The following profiles are both for user %1").arg(user_config.get_name().c_str()).toStdString();
 					}
 					error_msg += ":\n\n";
 					error_msg += user_config.get_profile_name();
@@ -773,17 +826,17 @@ int main( int argc, char ** argv )
 					error_msg += dup_user->get_profile_name();
 					error_msg += "\n\n";
 					if (cli_mode) {
-						error_msg += QString("You can only run multiple profiles for different users.").ascii();
+                        error_msg += QString("You can only run multiple profiles for different users.").toStdString();
 						error_msg += "\n";
-						error_msg += QString("If these are users for different domains, then enable the following option in your user profile (SIP protocol):");
+                        error_msg += QString("If these are users for different domains, then enable the following option in your user profile (SIP protocol):").toStdString();
 						error_msg += "\n";
-						error_msg += QString("Use domain name to create a unique contact header");
+                        error_msg += QString("Use domain name to create a unique contact header").toStdString();
 					} else {
-						error_msg += qApp->translate("GUI", "You can only run multiple profiles for different users.").ascii();
+                        error_msg += qApp->translate("GUI", "You can only run multiple profiles for different users.").toStdString();
 						error_msg += "\n";
-						error_msg += qApp->translate("GUI", "If these are users for different domains, then enable the following option in your user profile (SIP protocol)");
+                        error_msg += qApp->translate("GUI", "If these are users for different domains, then enable the following option in your user profile (SIP protocol)").toStdString();
 						error_msg += ":\n";
-						error_msg += qApp->translate("GUI", "Use domain name to create a unique contact header");
+                        error_msg += qApp->translate("GUI", "Use domain name to create a unique contact header").toStdString();
 					}
 					ui->cb_show_msg(error_msg, MSG_CRITICAL);
 					profile_selected = false;
@@ -909,33 +962,6 @@ int main( int argc, char ** argv )
 		log_msg += "\n";
 		log_file->write_report(log_msg, "::main", LOG_NORMAL, LOG_WARNING);
 	}
-	
-	// Dedicated thread will catch SIGALRM, SIGINT, SIGTERM, SIGCHLD signals, 
-	// therefore all threads must block these signals. Block now, then all
-	// created threads will inherit the signal mask.
-	// In LinuxThreads the sigwait does not work very well, so
-	// in LinuxThreads a signal handler is used instead.
-	if (!threading_is_LinuxThreads) {
-		sigset_t sigset;
-		sigemptyset(&sigset);
-		sigaddset(&sigset, SIGALRM);
-		sigaddset(&sigset, SIGINT);
-		sigaddset(&sigset, SIGTERM);
-		sigaddset(&sigset, SIGCHLD);
-		sigprocmask(SIG_BLOCK, &sigset, NULL);
-	} else {
-		if (!phone->set_sighandler()) {
-			string msg = "Failed to register signal handler.";
-			log_file->write_report(msg, "::main", LOG_NORMAL, LOG_CRITICAL);
-			ui->cb_show_msg(msg, MSG_CRITICAL);
-			sys_config->delete_lock_file();
-			exit(1);
-		}
-	}
-	
-	// Ignore SIGPIPE so read from broken sockets will not cause
-	// the process to terminate.
-	(void)signal(SIGPIPE, SIG_IGN);
 				 
 	// Create threads
 	t_thread *thr_sender;
@@ -1022,6 +1048,24 @@ int main( int argc, char ** argv )
 	} catch (string e) {
 		string msg = "Exception: ";
 		msg += e;
+		log_file->write_report(msg, "::main", LOG_NORMAL, LOG_CRITICAL);
+		ui->cb_show_msg(msg, MSG_CRITICAL);
+		sys_config->delete_lock_file();
+		exit(1);
+	} catch (int e) {
+		string msg = "Error code exception: ";
+		msg += e;
+		log_file->write_report(msg, "::main", LOG_NORMAL, LOG_CRITICAL);
+		ui->cb_show_msg(msg, MSG_CRITICAL);
+		sys_config->delete_lock_file();
+		exit(1);
+	} catch (const std::exception& e) {
+		string msg = "std::exception exception: ";
+		msg += e.what();
+		msg += " (";
+		msg += typeid(e).name();
+		msg += ")";
+		
 		log_file->write_report(msg, "::main", LOG_NORMAL, LOG_CRITICAL);
 		ui->cb_show_msg(msg, MSG_CRITICAL);
 		sys_config->delete_lock_file();
@@ -1175,9 +1219,9 @@ int main( int argc, char ** argv )
 		translator = NULL;
 	}
 	
-	if (qtranslator) {
-		MEMMAN_DELETE(qtranslator);
-		delete(qtranslator);
+	if (appTranslator) {
+		MEMMAN_DELETE(appTranslator);
+		delete(appTranslator);
 	}
 	
 	if (qa) {
