@@ -76,6 +76,7 @@ using namespace utils;
 #define FLD_GUI_AUTO_SHOW_INCOMING	"gui_auto_show_incoming"
 #define FLD_GUI_AUTO_SHOW_TIMEOUT	"gui_auto_show_timeout"
 #define FLD_GUI_BROWSER_CMD	"gui_browser_cmd"
+#define FLD_GUI_SHOW_CALL_OSD	"gui_show_call_osd"
 
 // Address book settings
 #define FLD_AB_SHOW_SIP_ONLY	"ab_show_sip_only"
@@ -194,10 +195,10 @@ t_win_geometry::t_win_geometry(const string &value) {
 	vector<string> v = split(value, ',');
 	
 	if (v.size() == 4) {
-		x = atoi(v[0].c_str());
-		y = atoi(v[1].c_str());
-		width = atoi(v[2].c_str());
-		height = atoi(v[3].c_str());
+		x = std::stoi(v[0]);
+		y = std::stoi(v[1]);
+		width = std::stoi(v[2]);
+		height = std::stoi(v[3]);
 	}
 }
 
@@ -254,6 +255,7 @@ t_sys_settings::t_sys_settings() {
 	gui_hide_on_close = true;
 	gui_auto_show_incoming = false;
 	gui_auto_show_timeout = 10;
+	gui_show_call_osd = true;
 	
 	ab_show_sip_only = false;
 	ab_lookup_name = true;
@@ -634,6 +636,10 @@ bool t_sys_settings::get_show_buddy_list(void) const {
 	return result;
 }
 
+bool t_sys_settings::get_gui_show_call_osd() const {
+	return gui_show_call_osd;
+}
+
 string t_sys_settings::get_ui_session_id(void) const {
 	t_mutex_guard guard(mtx_sys);
 	return ui_session_id;
@@ -967,6 +973,12 @@ void t_sys_settings::set_warn_hide_user(bool b) {
 	warn_hide_user = b;
 }
 
+void t_sys_settings::set_gui_show_call_osd(bool b) {
+	// Using mutexes in primitive type getters/setters doesn't make any sense.
+	// TODO: remove t_mutex_guard from other getters/setters like this one.
+	gui_show_call_osd = b;
+}
+
 void t_sys_settings::set_mime_shared_database(const string &filename) {
 	t_mutex_guard guard(mtx_sys);
 	mime_shared_database = filename;
@@ -981,12 +993,12 @@ string t_sys_settings::about(bool html) const {
 	if (html) s += "<BR>";
 	s += "\n";
 	
-	s += "Copyright (C) 2005-2009  ";
+	s += "Copyright (C) 2005-2015  ";
 	s += PRODUCT_AUTHOR;
 	if (html) s += "<BR>";
 	s += "\n";
 
-	s += "http://www.twinklephone.com";
+	s += "http://twinkle.dolezel.info";
 	if (html) s += "<BR><BR>";
 	s += "\n\n";
 	
@@ -1044,6 +1056,11 @@ string t_sys_settings::about(bool html) const {
 	if (html) s += "<BR>";
 	s += "\n";
 #endif
+#ifdef HAVE_BCG729
+	s += TRANSLATE("* G729A codec (http://www.linphone.org/technical-corner/bcg729/overview");
+	if (html) s += "<BR>";
+	s += "\n";
+#endif
 	
 	s += TRANSLATE("* Parts of the STUN project at http://sourceforge.net/projects/stun");
 	if (html) s += "<BR>";
@@ -1064,7 +1081,7 @@ string t_sys_settings::about(bool html) const {
 	if (html) s += "<BR>";
 	s += "\n";
 
-	s += "* GNU CommonC++ - http://www.gnu.org/software/commoncpp";
+	s += "* GNU uCommon C++ - http://www.gnutelephony.org/index.php/Category:Software";
 	if (html) s += "<BR><BR>";
 	s += "\n\n";
 	
@@ -1109,8 +1126,8 @@ string t_sys_settings::get_product_date(void) const {
 	vector<string> l = split(PRODUCT_DATE, ' ');
 	assert(l.size() == 3);
 	t.tm_mon = str2month_full(l[0]);
-	t.tm_mday = atoi(l[1].c_str());
-	t.tm_year = atoi(l[2].c_str()) - 1900;
+	t.tm_mday = std::stoi(l[1]);
+	t.tm_year = std::stoi(l[2]) - 1900;
 	
 	char buf[64];
 	strftime(buf, 64, "%d %B %Y", &t);
@@ -1135,6 +1152,10 @@ string t_sys_settings::get_options_built(void) const {
 	if (!options_built.empty()) options_built += ", ";
 	options_built += "iLBC";
 #endif
+#ifdef HAVE_BCG729
+	if (!options_built.empty()) options_built += ", ";
+	options_built += "G729";
+#endif
 #ifdef HAVE_ZRTP
 	if (!options_built.empty()) options_built += ", ";
 	options_built += "ZRTP";
@@ -1565,6 +1586,8 @@ bool t_sys_settings::read_config(string &error_msg) {
 			gui_auto_show_timeout = atoi(value.c_str());
 		} else if (parameter == FLD_GUI_BROWSER_CMD) {
 			gui_browser_cmd = value;
+		} else if (parameter == FLD_GUI_SHOW_CALL_OSD) {
+			gui_show_call_osd = yesno2bool(value);
 		} else if (parameter == FLD_AB_SHOW_SIP_ONLY) {
 			ab_show_sip_only = yesno2bool(value);
 		} else if (parameter == FLD_AB_LOOKUP_NAME) {
@@ -1704,6 +1727,7 @@ bool t_sys_settings::write_config(string &error_msg) {
 	config << FLD_GUI_AUTO_SHOW_INCOMING << '=' << bool2yesno(gui_auto_show_incoming) << endl;
 	config << FLD_GUI_AUTO_SHOW_TIMEOUT << '=' << gui_auto_show_timeout << endl;
 	config << FLD_GUI_BROWSER_CMD << '=' << gui_browser_cmd << endl;
+	config << FLD_GUI_SHOW_CALL_OSD << '=' << bool2yesno(gui_show_call_osd) << endl;
 	config << endl;
 	
 	// Write address book settings
