@@ -151,6 +151,7 @@ private:
 	/** Show main window on incoming call after a few seconds */
 	bool		gui_auto_show_incoming;
 	int		gui_auto_show_timeout;
+	bool		gui_show_call_osd;
 	
 	/** Command to start an internet browser */
 	string		gui_browser_cmd;
@@ -294,6 +295,7 @@ public:
 	bool get_gui_auto_show_incoming(void) const;
 	int get_gui_auto_show_timeout(void) const;
 	string get_gui_browser_cmd(void) const;
+	bool get_gui_show_call_osd() const;
 	bool get_ab_show_sip_only(void) const;
 	bool get_ab_lookup_name(void) const;
 	bool get_ab_override_display(void) const;
@@ -349,6 +351,7 @@ public:
 	void set_gui_auto_show_incoming(bool b);
 	void set_gui_auto_show_timeout(int timeout);
 	void set_gui_browser_cmd(const string &s);
+	void set_gui_show_call_osd(bool b);
 	void set_ab_show_sip_only(bool b);
 	void set_ab_lookup_name(bool b);
 	void set_ab_override_display(bool b);
@@ -496,7 +499,7 @@ public:
 	 * @param error_msg [out] Error message if the operation fails.
 	 * @param already_running [out] If the operation fails, this flag indicates Twinkle
 	 *        is already running.
-	 * @return True if the file is locked succesfully.
+	 * @return True if the file is locked successfully.
 	 * @return False if the file could not be locked.
 	 */
 	bool create_lock_file(bool shared_lock, string &error_msg, bool &already_running);
