@@ -1001,7 +1001,7 @@ void t_userintf::do_dtmf(const string &digits) {
 	if (!call_info.dtmf_supported) return;
 	
 	for (string::const_iterator i = digits.begin(); i != digits.end(); i++) {
-		if (VALID_DTMF_SYM(*i)) {
+		if (is_valid_dtmf_sym(*i)) {
 			phone->pub_send_dtmf(*i, call_info.dtmf_inband, call_info.dtmf_info);
 		}
 	}
@@ -2172,6 +2172,7 @@ string t_userintf::format_codec(t_audio_codec codec) const {
 	case CODEC_G726_24:	return "g726-24";
 	case CODEC_G726_32:	return "g726-32";
 	case CODEC_G726_40:	return "g726-40";
+	case CODEC_G729A: return "g729a";
 	default:		return "???";
 	}
 }
@@ -2186,7 +2187,7 @@ void t_userintf::run(void) {
 
 	cout << PRODUCT_NAME << " " << PRODUCT_VERSION << ", " << PRODUCT_DATE;
 	cout << endl;
-	cout << "Copyright (C) 2005-2009  " << PRODUCT_AUTHOR << endl;
+	cout << "Copyright (C) 2005-2015  " << PRODUCT_AUTHOR << endl;
 	cout << endl;
 	
 	cout << "Users:";
@@ -2225,6 +2226,10 @@ void t_userintf::run(void) {
 	cout << endl;
 }
 
+void t_userintf::run_on_event_queue(std::function<void()> fn) {
+	evq_ui_events.push_fncall(fn);
+}
+
 void t_userintf::process_events(void) {
 	t_event		*event;
 	t_event_ui	*ui_event;
@@ -2241,6 +2246,9 @@ void t_userintf::process_events(void) {
 		case EV_QUIT:
 			quit = true;
 			break;
+		case EV_FN_CALL:
+			static_cast<t_event_fncall*>(event)->invoke();
+			break;
 		default:
 			assert(false);
 			break;
@@ -2931,13 +2939,13 @@ void t_userintf::cb_stop_call_notification(int line) {
 	cb_stop_tone(line);
 }
 
-void t_userintf::cb_dtmf_detected(int line, char dtmf_event) {
+void t_userintf::cb_dtmf_detected(int line, t_dtmf_ev dtmf_event) {
 	if (line >= NUM_USER_LINES) return;
 	
 	cout << endl;
 	cout << "Line " << line + 1 << ": DTMF detected: ";
 
-	if (VALID_DTMF_EV(dtmf_event)) {
+	if (is_valid_dtmf_ev(dtmf_event)) {
 		cout << dtmf_ev2char(dtmf_event) << endl;
 	} else {
 		cout << "invalid DTMF telephone event (" << (int)dtmf_event << endl;
@@ -2947,22 +2955,22 @@ void t_userintf::cb_dtmf_detected(int line, char dtmf_event) {
 	cout.flush();
 }
 
-void t_userintf::cb_async_dtmf_detected(int line, char dtmf_event) {
+void t_userintf::cb_async_dtmf_detected(int line, t_dtmf_ev dtmf_event) {
 	if (line >= NUM_USER_LINES) return;
 	
 	t_event_ui *event = new t_event_ui(TYPE_UI_CB_DTMF_DETECTED);
 	MEMMAN_NEW(event);
 	
 	event->set_line(line);
-	event->set_dtmf_event(dtmf_event);	
+	event->set_dtmf_event(dtmf_event);
 	evq_ui_events.push(event);
 }
 
-void t_userintf::cb_send_dtmf(int line, char dtmf_event) {
+void t_userintf::cb_send_dtmf(int line, t_dtmf_ev dtmf_event) {
 	// No feed back in CLI
 }
 
-void t_userintf::cb_async_send_dtmf(int line, char dtmf_event) {
+void t_userintf::cb_async_send_dtmf(int line, t_dtmf_ev dtmf_event) {
 	t_event_ui *event = new t_event_ui(TYPE_UI_CB_SEND_DTMF);
 	MEMMAN_NEW(event);
 	
@@ -3055,7 +3063,7 @@ void t_userintf::cb_refer_result_success(int line) {
 	if (line >= NUM_USER_LINES) return;
 	
 	cout << endl;
-	cout << "Line " << line + 1 << ": call succesfully referred.\n";
+	cout << "Line " << line + 1 << ": call successfully referred.\n";
 	cout << endl;
 	cout.flush();
 }
@@ -3089,7 +3097,7 @@ void t_userintf::cb_call_referred(t_user *user_config, int line, t_request *r) {
 	cout << endl;
 
 	if (r->hdr_referred_by.is_populated()) {
-		cout << "Tranfer requested by ";
+		cout << "Transfer requested by ";
 		cout << format_sip_address(user_config, r->hdr_referred_by.display,
 			r->hdr_referred_by.uri);
 		cout << endl;
